Attribute VB_Name = "Startup"
Option Explicit

Public Const ALERT_TITLE As String = "ASCOM Phidget Focuser"

'
' ASCOM Identifiers
'
Public Const ID As String = "PhidgetFocus.Focuser"
Private Const DESC As String = "PhidgetFocus"
Private Const RegVer As String = "1.1"

' ---------
' Variables
' ---------

Public g_Profile As DriverHelper.Profile
Public g_bRunExecutable As Boolean
Public g_iConnections As Integer

' ---------------
' State Variables
' ---------------

Public g_lMinDeg As Long       ' Minimum position
Public g_lMaxDeg As Long       ' Maximum position
Public g_dStepSize As Double    ' Step size in microns

' ----------------------
' Other global variables
' ----------------------

Public g_handBox As frmHandBox             ' Hand box
Public g_show As frmShow                   ' Traffic window
Public g_bAlwaysTop As Boolean             ' True to keep sim topmost window

Public Servo As PhidgetServo




'---------------------------------------------------------------------
'
' Main() - Simulator main entry point
'
'---------------------------------------------------------------------

Sub Main()
  
    Set g_handBox = New frmHandBox
    Set g_Profile = New DriverHelper.Profile
    g_Profile.DeviceType = "Focuser"          ' We're a Focuser driver
      
    If App.StartMode = vbSModeStandalone Then
        g_bRunExecutable = True                     ' launched via double click
    Else
        g_bRunExecutable = False                    ' running as server only
    End If
    
    g_iConnections = 0                              ' zero connections currently
    
    g_Profile.Register ID, DESC ' Self reg (skips if already reg)
    
    '
    ' Persistent settings - Create on first start as determined by
    ' existence of most recently added setting
    '
    If g_Profile.GetValue(ID, "RegVer") <> RegVer Then
        g_Profile.WriteValue ID, "RegVer", RegVer
        g_Profile.WriteValue ID, "MinDeg", "30"
        g_Profile.WriteValue ID, "MaxDeg", "200"
        g_Profile.WriteValue ID, "StepSize", "20.0"
        g_Profile.WriteValue ID, "AlwaysOnTop", "True"
        g_Profile.WriteValue ID, "Left", "100"
        g_Profile.WriteValue ID, "Top", "100"
    End If
    
    g_lMinDeg = CLng(g_Profile.GetValue(ID, "MinDeg"))
    g_lMaxDeg = CLng(g_Profile.GetValue(ID, "MaxDeg"))
    g_bAlwaysTop = CBool(g_Profile.GetValue(ID, "AlwaysOnTop"))
    g_dStepSize = CDbl(g_Profile.GetValue(ID, "StepSize"))

    Load frmSetup
    
    '
    ' Show the handbox now and start the timer
    '
    Load g_handBox
    
    g_handBox.Left = CLng(g_Profile.GetValue(ID, "Left")) * Screen.TwipsPerPixelX
    g_handBox.Top = CLng(g_Profile.GetValue(ID, "Top")) * Screen.TwipsPerPixelY
    '
    ' Fix bad positions (which shouldn't ever happen, ha ha)
    '
    If g_handBox.Left < 0 Then
        g_handBox.Left = 100 * Screen.TwipsPerPixelX
        g_Profile.WriteValue ID, "Left", CStr(g_handBox.Left \ Screen.TwipsPerPixelX)
    End If
    If g_handBox.Top < 0 Then
        g_handBox.Top = 100 * Screen.TwipsPerPixelY
        g_Profile.WriteValue ID, "Top", CStr(g_handBox.Top \ Screen.TwipsPerPixelY)
    End If
    
    If g_bRunExecutable Then
        g_handBox.WindowState = vbNormal
    Else
        g_handBox.WindowState = vbMinimized
    End If
    
    g_handBox.Show
    
End Sub

'---------------------------------------------------------------------
'
' DoShutdown() - Handle handbox form Unload event
'
' Save form values for restoration on next start.
' Also "closes" the focuser connection.
'---------------------------------------------------------------------

Sub DoShutdown()
    g_handBox.Visible = True
    g_handBox.WindowState = vbNormal
    g_Profile.WriteValue ID, "Left", CStr(g_handBox.Left \ Screen.TwipsPerPixelX)
    g_Profile.WriteValue ID, "Top", CStr(g_handBox.Top \ Screen.TwipsPerPixelY)
        
End Sub

'---------------------------------------------------------------------
'
' DoSetup() - Handle handbox Setup button click
'
'---------------------------------------------------------------------

Sub DoSetup()
    
    With frmSetup
        .AllowUnload = False                        ' Assure not unloaded
        .MinDeg = g_lMinDeg
        .MaxDeg = g_lMaxDeg
        .StepSize = g_dStepSize
        .chkAlwaysTop = IIf(g_bAlwaysTop, 1, 0)
    End With

    g_handBox.Visible = False                       ' May float over setup
    FloatWindow frmSetup.hwnd, True
    frmSetup.Show 1

    With frmSetup
        If .Result Then             ' Unless cancelled
            g_lMinDeg = .MinDeg
            g_Profile.WriteValue ID, "MinDeg", CStr(g_lMinDeg)
            g_lMaxDeg = .MaxDeg
            g_Profile.WriteValue ID, "MaxDeg", CStr(g_lMaxDeg)
            g_dStepSize = .StepSize
            g_Profile.WriteValue ID, "StepSize", CStr(g_dStepSize)
            g_bAlwaysTop = (.chkAlwaysTop = 1)
            g_Profile.WriteValue ID, "AlwaysOnTop", CStr(g_bAlwaysTop)
                        
        End If
        .AllowUnload = True                     ' OK to unload now
    End With

    FloatWindow g_handBox.hwnd, g_bAlwaysTop
    g_handBox.Visible = True
End Sub

Public Property Get fromDegrees(ByVal deg As Single) As Long
    ' convert from motorPosition to ascom steps
    fromDegrees = 0.5 + 10 * (deg - g_lMinDeg)
End Property

Public Property Get toDegrees(ByVal pos As Long) As Single
    ' convert from ascom steps to motorPosition
    toDegrees = (0.1 * pos) + g_lMinDeg
End Property

